@@ -61,7 +61,7 @@ try:
 except:
     pass
         
-command = shlex.split("python2.5 " + daemonFile)
+command = shlex.split("python " + daemonFile)
 proc = subprocess.Popen(command, shell=False)
 
 pdFile = open(pidFile, 'w+')
